==> haskell-th-lift-0.7.7-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.7
id: th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU
key: th-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU
license: BSD3
copyright: © 2006 Ian Lynagh, © 2010-2014 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
author: Ian Lynagh
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.Lift
abi: 84b4af8038e4d3e40fa101158d0ce5f8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-0.7.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-0.7.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-lift-0.7.7
hs-libraries: HSth-lift-0.7.7-4Fh2JOKcGGMJqOzEylnfxU
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-0.7.8-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift
version: 0.7.8
id: th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
key: th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
license: BSD3
copyright: © 2006 Ian Lynagh, © 2010-2014 Mathieu Boespflug
maintainer: Mathieu Boespflug <mboes@tweag.net>
homepage: http://github.com/mboes/th-lift
synopsis: Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s Lift class for datatypes.
category: Language
author: Ian Lynagh
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.TH.Lift
abi: 6224139908b1c6858ff98942b343da24
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-0.7.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-0.7.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/th-lift-0.7.8
hs-libraries: HSth-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html: /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
